==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24InvocationKeyHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$InvocationKeyHandler

// class file dependencies
// @dep_class b920d196013f4f61 java_awt_event_KeyAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 97eab495237ebae1 javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler

// header file dependencies
// @dep_header java_awt_event_KeyAdapter

#include "java/awt/event/KeyAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$method$keyReleased$c1315bcf69bed992(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$method_info$keyReleased$c1315bcf69bed992;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vmethods {
	void	(*keyReleased$c1315bcf69bed992)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_KeyAdapter$vmethods	java_awt_event_KeyAdapter;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler;
    _jc_java_awt_event_KeyAdapter$sub_refs	java_awt_event_KeyAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_KeyAdapter$sub_nonrefs	java_awt_event_KeyAdapter;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicComboPopup__24InvocationKeyHandler.h <==
// public class javax.swing.plaf.basic.BasicComboPopup$InvocationKeyHandler

// class file dependencies
// @dep_class b920d196013f4f61 java_awt_event_KeyAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 97eab495237ebae1 javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler

// header file dependencies
// @dep_header java_awt_event_KeyAdapter

#include "java/awt/event/KeyAdapter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler_H_

// Forward structure declarations
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicComboPopup$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$refs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtable	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$method$_init$57edbc699feab65e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicComboPopup$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$method$keyReleased$c1315bcf69bed992(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$method_info$keyReleased$c1315bcf69bed992;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vmethods {
	void	(*keyReleased$c1315bcf69bed992)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_KeyAdapter$vmethods	java_awt_event_KeyAdapter;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vmethods	javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicComboPopup$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_refs	javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler;
    _jc_java_awt_event_KeyAdapter$sub_refs	java_awt_event_KeyAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_KeyAdapter$sub_nonrefs	java_awt_event_KeyAdapter;
    _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$object {
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$vtype _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicComboPopup__24InvocationKeyHandler_H_ */
